Introduction
============

**radish** is a *Behaviour Driven Development*-Tool completely written in python.

Why yet another python BDD tool?
--------------------------------

In addition to the standard gherkin language features which almost every BDD tool tries to implement radish implements uncommon but useful features like Scenario Loops, Scenario Preconditions and Variables.
